/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.connector.commands;

import static com.openexchange.usm.connector.commands.CommandConstants.MAIL;
import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.json.JSONObject;

import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
import com.openexchange.usm.api.contenttypes.MailContentType;
import com.openexchange.usm.api.exceptions.USMException;
import com.openexchange.usm.json.*;
import com.openexchange.usm.json.response.ResponseObject;
import com.openexchange.usm.json.response.ResponseStatusCode;
import com.openexchange.usm.mimemail.MimeMailBuilder;

/**
 * Handler for the SendMail USM-JSON-Command.
 * @author ldo
 *
 */
public class SendMailHandler extends NormalCommandHandler {
	private static final String[] REQUIRED_PARAMETERS = { SESSIONID, MAIL };
	private static final String[] OPTIONAL_PARAMETERS = {};

	public SendMailHandler(USMJSONServlet servlet, HttpSession httpSession, JSONObject parameters, HttpServletRequest request)
			throws USMJSONAPIException {
		super(servlet, httpSession, parameters, request);
	}

	@Override
	public ResponseObject handleRequest() throws USMJSONAPIException {

		JSONObject data = getJSONObject(_parameters, MAIL);
		if (data == null)
			throw new USMJSONAPIException(ConnectorBundleErrorCodes.SEND_MAIL_MISSING_DATA_ERROR,
					ResponseStatusCode.WRONG_MISSING_PARAMETERS, "wrong parameter mail by SendMail");

		MimeMailBuilder mimeMailBuilder = new MimeMailBuilder();
		// convert JSON structure to mime mail
		String mimeMail = mimeMailBuilder.convertJSONObjectToMimeMail(data, false);
		MailContentType mailContentType = (MailContentType) _servlet.getContentTypeManager().getContentType(
				DefaultContentTypes.MAIL_ID);
		try {
			//send mail to server
			mailContentType.sendMail(mimeMail, _session);
		} catch (USMException e) {
			throw USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.SEND_MAIL_SENDMAIL_ACTION_ERROR, e);
		}
		return new ResponseObject(ResponseStatusCode.SUCCESS);
	}

	@Override
	protected String[] getOptionalParameters() {
		return OPTIONAL_PARAMETERS;
	}

	@Override
	protected String[] getRequiredParameters() {
		return REQUIRED_PARAMETERS;
	}
}
